# SApiPy _(ˈsapi pʌɪ)_
A Python interface for the Solar Analytics API.

## Resources:
* Solar Analytics: https://www.solaranalytics.com.au/
* API Docs: https://api-docs.solaranalytics.com/home.html?urls.primaryName=SA%20Public%20API
